@@ -2,29 +2,38 @@
 ### SNP injection
 ### -------------------------------------------------------------------------
 
+.keep_snps_packages <- function(pkgs)
+{
+    idx1 <- which(substr(pkgs, 1, 8) == "SNPlocs.")
+    idx2 <- which(substr(pkgs, 1, 12) == "XtraSNPlocs.")
+    idx <- c(idx1, idx2)
+    pkgs[idx]
+}
+
 installed.SNPs <- function()
 {
     pkgs <- installed.packages()[ , "Package"]
-    pkgs <- pkgs[substr(pkgs, 1, 8) == "SNPlocs."]
+    pkgs <- .keep_snps_packages(pkgs)
     names(pkgs) <- NULL
     return(pkgs)
 }
 
 available.SNPs <- function(type=getOption("pkgType"))
 {
-    url <- getDataAnnotationContribUrl(type)
-    pkgs <- available.packages(url)[, "Package"]
-    pkgs <- pkgs[substr(pkgs, 1, 8) == "SNPlocs."]
+    contrib_url <- get_data_annotation_contrib_url(type)
+    pkgs <- available.packages(contrib_url)[, "Package"]
+    pkgs <- .keep_snps_packages(pkgs)
     names(pkgs) <- NULL
     return(pkgs)
 }
 
 setGeneric("injectSNPs", signature="x",
-    function(x, SNPlocs_pkgname) standardGeneric("injectSNPs")
+    function(x, snps) standardGeneric("injectSNPs")
 )
 
+### 'snps' can be a SNPlocs object or the name of a SNPlocs package.
 setMethod("injectSNPs", "BSgenome",
-    function(x, SNPlocs_pkgname)
+    function(x, snps)
     {
         if (!is.null(SNPlocs_pkgname(x)))
             stop("SNPs were already injected in genome 'x'. ",
@@ -32,7 +41,7 @@ setMethod("injectSNPs", "BSgenome",
         ans <- x
         ## We want the original sequence names, not the user sequence names,
         ## so we use 'seqnames(x@seqinfo)' instead of 'seqnames(x)'.
-        ans@injectSNPs_handler <- InjectSNPsHandler(SNPlocs_pkgname,
+        ans@injectSNPs_handler <- InjectSNPsHandler(snps,
                                                     x@pkgname,
                                                     seqnames(x@seqinfo))
         ans@.seqs_cache <- new.env(parent=emptyenv())
