@@ -5,13 +5,11 @@
 
 get_data_annotation_contrib_url <- function(type=getOption("pkgType"))
 {
-    ## The BiocInstaller package is needed for biocinstallRepos().
-    if (!requireNamespace("BiocInstaller", quietly=TRUE)) {
-        ## Sourcing this file will install and load the BiocInstaller package.
-        suppressWarnings(source("http://bioconductor.org/biocLite.R",
-                                local=TRUE))
+    ## The BiocManager package is needed for repositories().
+    if (!requireNamespace("BiocManager", quietly=TRUE)) {
+        stop("Install 'BiocManager' from CRAN to get 'BioCann' contrib.url")
     }
-    contrib.url(BiocInstaller::biocinstallRepos()["BioCann"], type=type)
+    contrib.url(BiocManager::repositories()["BioCann"], type=type)
 }
 
 ### TODO: Move this to GenomeInfoDb.
