@@ -1,15 +1,16 @@
 ### R code from vignette source 'BSgenomeForge.Rnw'
+### Encoding: UTF-8
 
 ###################################################
-### code chunk number 1: BSgenomeForge.Rnw:192-195
+### code chunk number 1: BSgenomeForge.Rnw:193-196
 ###################################################
 library(Biostrings)
 file <- system.file("extdata", "ce2chrM.fa.gz", package="BSgenome")
-fasta.info(file)
+fasta.seqlengths(file)
 
 
 ###################################################
-### code chunk number 2: BSgenomeForge.Rnw:428-439
+### code chunk number 2: BSgenomeForge.Rnw:429-440
 ###################################################
 library(BSgenome)
 seed_files <- system.file("extdata", "GentlemanLab", package="BSgenome")
@@ -25,14 +26,14 @@ cat(readLines(rn4_seed), sep="\n")
 
 
 ###################################################
-### code chunk number 3: BSgenomeForge.Rnw:452-454 (eval = FALSE)
+### code chunk number 3: BSgenomeForge.Rnw:453-455 (eval = FALSE)
 ###################################################
 ## library(BSgenome)
 ## forgeBSgenomeDataPkg("path/to/my/seed")
 
 
 ###################################################
-### code chunk number 4: BSgenomeForge.Rnw:677-682
+### code chunk number 4: BSgenomeForge.Rnw:678-683
 ###################################################
 library(BSgenome)
 seed_files <- system.file("extdata", "GentlemanLab", package="BSgenome")
@@ -42,14 +43,14 @@ cat(readLines(rn4_masked_seed), sep="\n")
 
 
 ###################################################
-### code chunk number 5: BSgenomeForge.Rnw:697-699 (eval = FALSE)
+### code chunk number 5: BSgenomeForge.Rnw:698-700 (eval = FALSE)
 ###################################################
 ## library(BSgenome)
 ## forgeMaskedBSgenomeDataPkg("path/to/my/seed")
 
 
 ###################################################
-### code chunk number 6: BSgenomeForge.Rnw:741-742
+### code chunk number 6: BSgenomeForge.Rnw:742-743
 ###################################################
 sessionInfo()
 
