@@ -50,6 +50,7 @@ BSgenome_datapkgs <- c(
   "BSgenome.Ptroglodytes.UCSC.panTro2",
   "BSgenome.Ptroglodytes.UCSC.panTro3",
   "BSgenome.Ptroglodytes.UCSC.panTro5",
+  "BSgenome.Ptroglodytes.UCSC.panTro6",
   "BSgenome.Rnorvegicus.UCSC.rn4",
   "BSgenome.Rnorvegicus.UCSC.rn5",
   "BSgenome.Rnorvegicus.UCSC.rn6",
@@ -57,6 +58,7 @@ BSgenome_datapkgs <- c(
   "BSgenome.Scerevisiae.UCSC.sacCer2",
   "BSgenome.Scerevisiae.UCSC.sacCer3",
   "BSgenome.Sscrofa.UCSC.susScr3",
+  "BSgenome.Sscrofa.UCSC.susScr11",
   "BSgenome.Tguttata.UCSC.taeGut1",
   "BSgenome.Tguttata.UCSC.taeGut2"
 )
